@@ -17,6 +17,7 @@ from .goto_assignements import GoToAssignmentsMode
 from .indenter import PyIndenterMode
 from .sh import PythonSH
 from .pep8_checker import PEP8CheckerMode
+from .auto_pep8 import AutoPEP8
 
 
 try:
@@ -40,4 +41,5 @@ __all__ = [
     'PyAutoIndentMode',
     'PyIndenterMode',
     'PythonSH',
+    'AutoPEP8'
 ]
